@@ -1,14 +1,15 @@
 module Control.ReaperSpec (spec) where
 
-import Control.Concurrent
-import Control.Reaper
-import Data.IORef
+-- import Control.Concurrent
+-- import Control.Reaper
+-- import Data.IORef
 import Test.Hspec
-import Test.Hspec.QuickCheck
 
+-- import Test.Hspec.QuickCheck
 
 spec :: Spec
 spec = return ()
+
 --   prop "works" $ \is -> do
 --     reaper <- mkReaper defaultReaperSettings
 --         { reaperAction = action
